@@ -13,8 +13,6 @@ from typing import Generator, List, Optional, Tuple
 
 import bitmath
 import click
-from applescript import ScriptError
-from photoscript import PhotosLibrary
 from rich.console import Console
 from rich.layout import Layout
 from rich.live import Live
@@ -22,10 +20,17 @@ from rich.panel import Panel
 
 from osxphotos import PhotoInfo, PhotosDB
 from osxphotos._constants import _UNKNOWN_PERSON, search_category_factory
+from osxphotos.platform import assert_macos
 from osxphotos.rich_utils import add_rich_markup_tag
-from osxphotos.text_detection import detect_text as detect_text_in_photo
 from osxphotos.utils import dd_to_dms_str
 
+assert_macos()
+
+from applescript import ScriptError
+from photoscript import PhotosLibrary
+
+from osxphotos.text_detection import detect_text as detect_text_in_photo
+
 from .cli_params import DB_OPTION, THEME_OPTION
 from .color_themes import get_theme
 from .common import get_photos_db
@@ -86,8 +91,19 @@ def inspect_photo(
     photo: PhotoInfo,
     detected_text: Optional[str] = None,
     templates: Optional[List[str]] = None,
+    beta: bool = False,
 ) -> str:
-    """Get info about an osxphotos PhotoInfo object formatted for printing"""
+    """Get info about an osxphotos PhotoInfo object formatted for printing
+
+    Args:
+        photo: PhotoInfo object to inspect
+        detected_text: text detected in photo
+        templates: list of templates to render for photo
+        beta: if True, include beta properties in output
+
+    Returns:
+        str: formatted string with photo info
+    """
 
     if templates:
         return inspect_photo_templates(photo, templates)
@@ -171,16 +187,35 @@ def inspect_photo(
     if photo.moment_info:
         properties.append(bold("Moment: ") + f"{photo.moment_info.title or '-'}")
 
-    if photo.comments:
-        comments = [f"{c.user}: {c.text}" for c in photo.comments]
+    if photo.shared_moment:
+        info = photo.shared_moment_info
+        title = info.title if info else "-"
+        expiry = info.expiry_date.isoformat() if info and info.expiry_date else "-"
+        share_url = info.share_url if info else "-"
         properties.append(
-            bold("Comments: ") + trim(f"{', '.join(comments)}", "Comments: ")
+            bold("Shared Moment: ")
+            + trim(f"{title} expiry: {expiry} url: {share_url}", "Shared Moment: ")
         )
 
-    if photo.likes:
+    if photo.shared:
+        properties.append(bold("Owner: ") + f"{photo.owner or '-'}")
+        comments = [f"{c.user}: {c.text}" for c in photo.comments]
+        properties.append(
+            bold("Comments: ") + trim(f"{', '.join(comments) or '-'}", "Comments: ")
+        )
         properties.append(
             bold("Likes: ")
-            + trim(f"{', '.join(l.user for l in photo.likes)}", "Likes: ")
+            + trim(f"{', '.join(l.user for l in photo.likes) or '-'}", "Likes: ")
+        )
+
+    if beta and photo.shared_library:
+        share_participants = ", ".join(
+            f"{p.name_components.given_name} {p.name_components.family_name}{' (current user)' if p.is_current_user else ''}"
+            for p in photo.share_participant_info
+        )
+        properties.append(
+            bold("Share participant: ")
+            + trim(share_participants, "Share participant: ")
         )
 
     properties.append(format_exif_info(photo))
@@ -255,6 +290,13 @@ def format_flags(photo: PhotoInfo) -> str:
         flags.append("in cloud")
     if photo.shared:
         flags.append("shared")
+    if photo.syndicated:
+        flags.append("syndicated")  # sourcery skip
+        flags.append(
+            "saved to library" if photo.saved_to_library else "not saved to library"
+        )
+    if photo.shared_library:
+        flags.append("shared iCloud library")
 
     flag_str += f"{', '.join(flags) or '-'}"
     return flag_str
@@ -308,10 +350,8 @@ def format_paths(photo: PhotoInfo) -> str:
 
 def format_exif_info(photo: PhotoInfo) -> str:
     """Format exif_info for inspect_photo"""
-    exif_str = bold("EXIF: ")
     exif = photo.exif_info
-    if not exif:
-        return f"{exif_str}-"
+    exif_str = ""
 
     if exif.camera_make:
         exif_str += f"{exif.camera_make} "
@@ -349,7 +389,8 @@ def format_exif_info(photo: PhotoInfo) -> str:
         exif_str += f"{exif.codec}"
     if exif.track_format:
         exif_str += f"{exif.track_format}"
-    return exif_str
+
+    return bold("EXIF: ") + (exif_str or "-")
 
 
 def get_photo_type(photo: PhotoInfo) -> str:
@@ -445,7 +486,8 @@ def make_layout() -> Layout:
 )
 @THEME_OPTION
 @DB_OPTION
-def photo_inspect(db, theme, detect_text, template):
+@click.option("--beta", is_flag=True, help="Include beta properties in output")
+def photo_inspect(db, theme, detect_text, template, beta):
     """Interactively inspect photos selected in Photos.
 
     Open Photos then run `osxphotos inspect` in the terminal.
@@ -495,6 +537,7 @@ def photo_inspect(db, theme, detect_text, template):
         last_uuid = None
         uuid = None
         total = 0
+        width = Console().width
         while True:
             try:
                 uuid, total = get_uuid_for_photos_selection()
@@ -504,7 +547,9 @@ def photo_inspect(db, theme, detect_text, template):
                 # allow Ctrl+C to quit
                 break
             finally:
-                if uuid and uuid != last_uuid:
+                if uuid and (uuid != last_uuid or width != Console().width):
+                    # new photo selected or terminal resized
+                    width = Console().width
                     if total > 1:
                         update_status(
                             f"{total} photos selected; inspecting uuid={uuid}"
@@ -519,6 +564,7 @@ def photo_inspect(db, theme, detect_text, template):
                                     photo,
                                     detected_text=detected_text_cache.get(uuid, None),
                                     templates=template,
+                                    beta=beta,
                                 ),
                                 title=photo.title or photo.original_filename,
                             )
